@@ -23,6 +23,7 @@ use HTML::Mason::Exceptions;
 use CGI;
 use EBox::Gettext;
 use EBox;
+use EBox::Global;
 use EBox::Exceptions::Base;
 use EBox::Exceptions::Internal;
 use EBox::Exceptions::External;
@@ -34,6 +35,8 @@ use Data::Dumper;
 use Perl6::Junction qw(all);
 use File::Temp qw(tempfile);
 use File::Basename;
+use Apache2::Connection;
+use Apache2::RequestUtil;
 
 ## arguments
 ##		title [optional]
@@ -56,6 +59,13 @@ sub new # (title=?, error=?, msg=?, cgi=?, template=?)
 	}
 	$self->{domain} = 'ebox';
 	$self->{paramsKept} = ();
+
+	# XXX workaround form utf8 hell
+	if (Encode::is_utf8($self->{title})) {
+	  Encode::_utf8_off($self->{title});
+	}
+
+
 	bless($self, $class);
 	return $self;
 }
@@ -72,18 +82,15 @@ sub _menu
 sub _title
 {
 	my $self = shift;
+
+	my $title = $self->{title}; 
+	defined $title or $title = '';
+
 	my $filename = EBox::Config::templates . '/title.mas';
 	my $interp = $self->_masonInterp();
 	my $comp = $interp->make_component(comp_file => $filename);
-	my @params = ();
-	
-	my $title = $self->{title}; 
-	if (defined($title) and (length($title) > 0)) {
-		$title = __($title);
-	} else {
-		$title = "";
-	}
-	push(@params, 'title' => $title);
+
+	my @params = ( 'title' => $title);
 
 	settextdomain('ebox');
 	$interp->exec($comp, @params);
@@ -297,8 +304,24 @@ sub run
 	} 
 
 	if ((defined($self->{redirect})) && (!defined($self->{error}))) {
-		print($self->cgi()->redirect("/ebox/" . $self->{redirect}));
-		EBox::debug("redirect: " . $self->{redirect});
+		my $request = Apache2::RequestUtil->request();
+		my $headers = $request->headers_in();
+		my $via = $headers->{'Via'}; 
+		my $host= $headers->{'Host'};
+		my $fwhost = $headers->{'X-Forwaded-Host'};
+		# If the connection comes from a Proxy, 
+		# redirects with the Proxy IP address
+		if (defined($via) and defined($fwhost)) {
+			$host = $fwhost; 
+		}
+		my $protocol; 
+		if ($request->subprocess_env('https')) {
+			$protocol = 'https';
+		} else {
+			$protocol = 'http';
+		}
+		my $url = "$protocol://${host}/ebox/" . $self->{redirect};
+		print($self->cgi()->redirect($url));
 		return;
 	} 
 
