@@ -27,6 +27,8 @@ use warnings;
 
 use Params::Validate qw(validate SCALAR ARRAYREF);
 
+# Group: Public methods
+
 # Constructor: new
 #
 #     This exception is taken to say the type of an argument is not
@@ -91,39 +93,73 @@ sub new
   return $self;
 }
 
-
-
-sub _errorMsg
-{
-  my ($cmdType, $cmd, $error, $output, $exitValue) = @_;
-  my $errorStr = join ' ', @{ $error };
-  my $outputStr = join ' ', @{ $output };
-
-  return "$cmdType $cmd failed. \nError output: $errorStr\nCommand output: $outputStr. \nExit value: $exitValue";
-}
-
+# Method: cmd
+#
+#       Return the command string
+#
+# Returns:
+#
+#       String - the command string
+#
 sub cmd
 {
   my ($self) = @_;
   return $self->{cmd};
 }
 
+# Method: output
+#
+#       Return the standard output in an array
+#
+# Returns:
+#
+#       Array ref - the standard output, one line per element
+#
 sub output
 {
   my ($self) = @_;
   return $self->{output};
-} 
+}
 
+# Method: error
+#
+#       Return the standard error in an array
+#
+# Returns:
+#
+#       Array ref - the standard error, one line per element
+#
 sub error
 {
   my ($self) = @_;
   return $self->{error};
-} 
+}
 
+# Method: exitValue
+#
+#       Return the exit value
+#
+# Returns:
+#
+#       Int - the exit value
+#
 sub exitValue
 {
   my ($self) = @_;
   return $self->{exitValue};
-} 
+}
+
+# Group: Private methods
+sub _errorMsg
+{
+  my ($cmdType, $cmd, $error, $output, $exitValue) = @_;
+  my $errorStr = join ' ', @{ $error };
+  my $outputStr = join ' ', @{ $output };
+
+  $cmdType = '' unless defined($cmdType);
+
+  return "$cmdType $cmd failed. \nError output: $errorStr\nCommand output: $outputStr. \nExit value: $exitValue";
+}
+
 
 1;
