@@ -1,4 +1,5 @@
 # Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2006-2008 Warp Networks S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -17,7 +18,6 @@ package EBox::Gettext;
 
 use Locale::gettext;
 use EBox::Config;
-use Encode qw(:all);
 
 BEGIN {
 	use Exporter ();
@@ -71,13 +71,13 @@ sub __ # (text)
 	_set_packagedomain();
 	my $string = gettext(shift);
 	_unset_packagedomain();
-	_utf8_on($string);
 	return $string;
 }
 
 sub __n # (text)
 {
 	my $string = shift;
+	my ($p, $a, $c) = caller;
 	return $string;
 }
 
@@ -87,7 +87,6 @@ sub __x # (text, %variables)
 	_set_packagedomain();
 	my $string = gettext($msgid);
 	_unset_packagedomain();
-	_utf8_on($string);
 	return __expand($string, %vars);
 }
 
@@ -98,7 +97,6 @@ sub __d # (text,domain)
 	textdomain($domain);
 	$string = gettext($string);
 	textdomain($cur_domain);
-	_utf8_on($string);
 	return $string;
 }
 
@@ -140,7 +138,6 @@ sub _unset_packagedomain
 	}
 }
 
-use utf8;
 my $langs;
 $langs->{'an_ES.UTF-8'} = 'Aragonés';
 $langs->{'es_ES.UTF-8'} = 'Castellano';
@@ -151,14 +148,15 @@ $langs->{'C'} = 'English';
 $langs->{'eu_ES.UTF-8'} = 'Euskara';
 $langs->{'fr_FR.UTF-8'} = 'Français';
 $langs->{'it_IT.UTF-8'} = 'Italiano';
+$langs->{'ja_JP.UTF-8'} = '日本語';
 $langs->{'nl_BE.UTF-8'} = 'Nederlands';
 $langs->{'pl_PL.UTF-8'} = 'Polski';
 $langs->{'pt_BR.UTF-8'} = 'Português do Brasil';
 $langs->{'pt_PT.UTF-8'} = 'Português';
+$langs->{'bg_BG.UTF-8'} = 'Български';
 $langs->{'ru_RU.UTF-8'} = 'Русский';
 $langs->{'sv_SE.UTF-8'} = 'Svenska';
 $langs->{'tr_TR.UTF-8'} = 'Türkçe';
-no utf8;
 
 # Method:  langname
 #
