@@ -6,6 +6,7 @@ use warnings;
 use EBox::Test::Mason;
 use File::Basename;
 use Cwd;
+use Test::More;
 
 sub testComponent
 {
@@ -19,6 +20,8 @@ sub testComponent
   my $compRoot =   dirname dirname getcwd(); # XXX this is templates/input directory specific
   my $template =   (dirname getcwd()) . "/$component";
 
+  diag "\nComponent root $compRoot\n\n";
+
   foreach my $params (@{ $cases_r }) {
     EBox::Test::Mason::checkTemplateExecution(template => $template, templateParams => $params, compRoot => [$compRoot], printOutput => $printOutput, outputFile => $outputFile);
   }
