@@ -43,6 +43,7 @@ function addNewRow(url, table, fields, directory)
 			evalScripts: true,
 			onComplete: function(t) {
 			  stripe('dataTable', '#ecf5da', '#ffffff'); 
+			  completedAjaxRequest();
 			},
 			onFailure: function(t) {
 			  restoreHidden('buttons_' + table, table);
@@ -202,6 +203,7 @@ function changeView(url, table, directory, action, id, page, isFilter)
 			  if ( action == 'changeEdit' ) {
 			    restoreHidden('actionsCell_' + id, table);
 			  }
+			  completedAjaxRequest();
 			},
 			onFailure: function(t) {
 			  if ( action == 'changeAdd' ) {
@@ -270,14 +272,18 @@ function hangTable(successId, errorId, url, formId, loadingId)
 	method: 'post',
 	parameters: Form.serialize(formId, true), // The parameters are taken from the form
 	asynchronous: true,
-        evalScripts: true,
+    evalScripts: true,
+    onComplete: function(t) {
+      stripe('dataTable', '#ecf5da', '#ffffff'); 
+      completedAjaxRequest();
+    },
 	onFailure: function(t) {
 	  restoreHidden(loadingId);
 	}
       }
   );
  
-  //setLoading(loadingId);
+  setLoading(loadingId);
  
 }
 
@@ -375,17 +381,10 @@ function showSelected (selectId, nodeId, tableName)
 	var descendants = $(node).descendants();
 	if ( node.id == selectedValue ) {
 	  show( node.id );
-	  // Show not only the selected by its children
-	  descendants.each(function(desc) {
-		  show(desc.id);
-	      });
 	} 
 	else {
 	  // Hide not only the selected by its children
 	  hide( node.id );
-	  descendants.each(function(desc) {
-		  hide(desc.id);
-	      });
 	}
       }
     }
@@ -630,3 +629,49 @@ function inputValue(elementId) {
 	}
 }
 
+/*
+Function: markFileToRemove
+
+    This function is used along with the File view and setter to mark
+    a file to be removed
+
+Parameters:
+
+    elementId - a EBox::Types::File id
+*/
+function markFileToRemove(id)
+{
+    $(id + '_remove').value = "1";
+    hide(id + '_current');
+}
+
+/*
+Function: startAjaxRequest
+
+	This function is used to mark we start an ajax request.
+	This is used to help test using selenium, it modifies
+	a dom element -request_cookie- to be able to know when
+	an ajax request starts and stops.
+
+*/
+function startAjaxRequest()
+{
+    $('ajax_request_cookie').value = 1;
+}
+
+/*
+Function: completedAjaxRequest
+
+	This function is used to mark we finished an ajax request.
+	This is used to help test using selenium, it modifies
+	a dom element -request_cookie- to be able to know when
+	an ajax request starts and stops.
+
+*/
+function completedAjaxRequest()
+{
+    $('ajax_request_cookie').value = 0;
+}
+
+
+
